@@ -205,7 +205,7 @@ struct _zvtprivate
   struct zvt_background *background; /* background settings */
   struct zvt_background *background_queue; /* if set before realised */
   GdkPixmap *background_pixmap;	/* actual pixmap used to pre-draw background */
-  int background_watchsig;	/* signal to watch window movement */
+  GtkWidget *background_watch_window;	/* window we're tracking */
 
   unsigned short *queue_red, *queue_green, *queue_blue;
 
